/*
  COPYRIGHT NOTICE
  Copyright (c) 2012  Scott C. Neu and Arthur W. Toga

  This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

package edu.ucla.loni.freesurfer.plugin;

import edu.ucla.loni.freesurfer.MghFloat;
import java.util.ListResourceBundle;

/**
 * List Resource Bundle that provides descriptions for MGH elements.
 *
 * @version 16 March 2009
 */
public class MghMetadataFormatResources extends ListResourceBundle
{
    /** Constructs an MGH Metadata Format Resources. */
    public MghMetadataFormatResources()
    {
    }

    /**
     * Gets the contents of the Resource Bundle.
     *
     * @return Object array of the contents, where each item of the array is a
     *         pair of Objects.  The first element of each pair is the key,
     *         which must be a String, and the second element is the value
     *         associated with that key.
     */
    public Object[][] getContents()
    {
	String rootName = MghMetadataFormat.NATIVE_METADATA_FORMAT_NAME;
	String acquisition = MghMetadataFormat.ACQUISITION;
	String tag = MghMetadataFormat.TAG;

	Object[][] contents = {

	    // Node name + "/" + attribute name, followed by description
	    {rootName + "/" + MghMetadataFormat.VERSION,
	     "Version of the header."},
	    {rootName + "/" + MghMetadataFormat.WIDTH,
	     "Width of each image (in voxels)."},
	    {rootName + "/" + MghMetadataFormat.HEIGHT,
	     "Height of each image (in voxels)."},
	    {rootName + "/" + MghMetadataFormat.DEPTH,
	     "Number of images in a volume."},
	    {rootName + "/" + MghMetadataFormat.NFRAMES,
	     "Number of scalar components per voxel."},
	    {rootName + "/" + MghMetadataFormat.TYPE,
	     "Data type of the image."},
	    {rootName + "/" + MghMetadataFormat.DOF,
	     "Degrees of freedom."},
	    {rootName + "/" + MghMetadataFormat.SPACING_X,
	     "Voxel spacing in the X direction."},
	    {rootName + "/" + MghMetadataFormat.SPACING_Y,
	     "Voxel spacing in the Y direction."},
	    {rootName + "/" + MghMetadataFormat.SPACING_Z,
	     "Voxel spacing in the Z direction."},
	    {rootName + "/" + MghMetadataFormat.XR,
	     "Component of the X axis along the right direction."},
	    {rootName + "/" + MghMetadataFormat.XA,
	     "Component of the X axis along the anterior direction."},
	    {rootName + "/" + MghMetadataFormat.XS,
	     "Component of the X axis along the superior direction."},
	    {rootName + "/" + MghMetadataFormat.YR,
	     "Component of the Y axis along the right direction."},
	    {rootName + "/" + MghMetadataFormat.YA,
	     "Component of the Y axis along the anterior direction."},
	    {rootName + "/" + MghMetadataFormat.YS,
	     "Component of the Y axis along the superior direction."},
	    {rootName + "/" + MghMetadataFormat.ZR,
	     "Component of the Z axis along the right direction."},
	    {rootName + "/" + MghMetadataFormat.ZA,
	     "Component of the Z axis along the anterior direction."},
	    {rootName + "/" + MghMetadataFormat.ZS,
	     "Component of the Z axis along the superior direction."},
	    {rootName + "/" + MghMetadataFormat.CR,
	     "Right coordinate value of the volume center."},
	    {rootName + "/" + MghMetadataFormat.CA,
	     "Anterior coordinate value of the volume center."},
	    {rootName + "/" + MghMetadataFormat.CS,
	     "Superior coordinate value of the volume center."},

	    // Node name, followed by description
	    {acquisition, "Acquisition parameters."},
	    {acquisition + "/" + MghFloat.TR,
	     "Repetition time (in milliseconds)."},
	    {acquisition + "/" + MghFloat.FLIP_ANGLE,
	     "Flip angle (in radians)."},
	    {acquisition + "/" + MghFloat.TE,
	     "Echo time (in milliseconds)."},
	    {acquisition + "/" + MghFloat.TI,
	     "Inversion time (in milliseconds)."},
	    {acquisition + "/" + MghFloat.FOV,
	     "Field of view."},

	    {tag, "Optional tag."},
	    {tag + "/" + MghMetadataFormat.TAG_CODE, "Tag code."},
	    {tag + "/" + MghMetadataFormat.TAG_VALUE, "Tag value."}
	};

	return contents;
    }
}
