/*
COPYRIGHT NOTICE
Copyright (c) 2012  Scott C. Neu, Daniel J. Valentino, and Arthur W. Toga

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package edu.ucla.loni.ge.plugin;

import java.util.ListResourceBundle;
import edu.ucla.loni.ge.GESuiteInfo;
import edu.ucla.loni.ge.GEExamInfo;
import edu.ucla.loni.ge.GESeriesInfo;
import edu.ucla.loni.ge.GEImageInfo;
import edu.ucla.loni.ge.GEMRImageInfo;
import edu.ucla.loni.ge.GECTImageInfo;

/**
 * List Resource Bundle that provides descriptions for GE 7.5 elements.
 *
 * @version 4 June 2002
 */
public class GEMetadataFormatResources extends ListResourceBundle
{
  /** Constructs a GEMetadataFormatResources. */
  public GEMetadataFormatResources()
    {
    }

  /**
   * Gets the contents of the Resource Bundle.
   *
   * @return Object array of the contents, where each item of the array is a
   *         pair of Objects.  The first element of each pair is the key, which
   *         must be a String, and the second element is the value associated
   *         with that key.
   */
  public Object[][] getContents()
    {
      String suiteInfoName = GEMetadataFormat.GE_SUITE_INFO_NAME;
      String examInfoName = GEMetadataFormat.GE_EXAM_INFO_NAME;
      String seriesInfoName = GEMetadataFormat.GE_SERIES_INFO_NAME;
      String imageInfoName = GEMetadataFormat.GE_IMAGE_INFO_NAME;
      String mrImageInfoName = GEMetadataFormat.GE_MR_IMAGE_INFO_NAME;
      String ctImageInfoName = GEMetadataFormat.GE_CT_IMAGE_INFO_NAME;

      Object[][] contents = {

	  // Node name, followed by description
	  {suiteInfoName, "Describes the suite information."},
	  {examInfoName, "Describes the exam information."},
	  {seriesInfoName, "Describes the series information."},
	  {imageInfoName, "Describes the image information."},
	  {mrImageInfoName, "Describes the MR image information."},
	  {ctImageInfoName, "Describes the CT image information."},


	  // Node name + "/" + attribute name, followed by description
	  {suiteInfoName + "/" + GESuiteInfo.SUITE_ID,
	   "suite ID."},  
	  {suiteInfoName + "/" + GESuiteInfo.UNIQUE_FLAG,
	   "Make Unique Flag"},
	  {suiteInfoName + "/" + GESuiteInfo.DISK_ID,
	   "Disk ID"},
	  {suiteInfoName + "/" + GESuiteInfo.PRODUCT_ID,
	   "Product ID"},
  	  {suiteInfoName + "/" + GESuiteInfo.VERSION_CR,
	   "Genesis Version of Record Created"},
	  {suiteInfoName + "/" + GESuiteInfo.VERSION_CU,
	   "Genesis Version of Record Currently"},
	  {suiteInfoName + "/" + GESuiteInfo.CHECK_SUM,
	   "Suite Record Checksum"},

	  {examInfoName + "/" + GEExamInfo.SUITE_ID,
	   "suite ID."},
	  {examInfoName + "/" + GEExamInfo.UNIQUE_FLAG,
	   "Unique Flag."},
	  {examInfoName + "/" + GEExamInfo.DISK_ID,
	   "Disk ID for this Exam."},
	  {examInfoName + "/" + GEExamInfo.EXAM_NUMBER,
	   "Exam Number."},
	  {examInfoName + "/" + GEExamInfo.HOSPITAL_NAME,
	   "Hospital Name."},
	  {examInfoName + "/" + GEExamInfo.DETECTOR,
	   "Detector Type."},
	  {examInfoName + "/" + GEExamInfo.NUMBER_CELLS,
	   "Number of cells in det."},
	  {examInfoName + "/" + GEExamInfo.ZERO_CELL,
	   "Cell number at theta."},
	  {examInfoName + "/" + GEExamInfo.CELL_SPACE,
	   "Cell spacing."},
	  {examInfoName + "/" + GEExamInfo.SRC_TO_DET,
	   "Distance from source to detector."},
	  {examInfoName + "/" + GEExamInfo.SRC_TO_ISO,
	   "Distance from source to iso."},
	  {examInfoName + "/" + GEExamInfo.TUBE_TYPE,
	   "Tube type."},
	  {examInfoName + "/" + GEExamInfo.DAS_TYPE,
	   "DAS type."},
	  {examInfoName + "/" + GEExamInfo.NUMBER_DECON_KERNALS,
	   "Number of Decon Kernals."},
	  {examInfoName + "/" + GEExamInfo.DECON_LEN,
	   "Number of elements in a Decon Kernal."},
	  {examInfoName + "/" + GEExamInfo.DECON_DENSITY,
	   "Decon Kernal density."},
	  {examInfoName + "/" + GEExamInfo.DECON_STEP_SIZE,
	   "Decon Kernal stepsize."},
	  {examInfoName + "/" + GEExamInfo.DECON_SHIFT_CNT,
	   "Decon Kernal Shift Count."},
	  {examInfoName + "/" + GEExamInfo.MAG_STRENGTH,
	   "Magnet strength (in gauss)."},
	  {examInfoName + "/" + GEExamInfo.PATIENT_ID,
	   "Patient ID for this Exam."},
	  {examInfoName + "/" + GEExamInfo.PATIENT_NAME,
	   "Patient Name."},
	  {examInfoName + "/" + GEExamInfo.PATIENT_AGE,
	   "Patient Age (years, months or days)."},
	  {examInfoName + "/" + GEExamInfo.PATIENT_AGE_NOT,
	   "Patient Age Notation."},
	  {examInfoName + "/" + GEExamInfo.PATIENT_SEX,
	   "Patient Sex."},
	  {examInfoName + "/" + GEExamInfo.PATIENT_WEIGHT,
	   "Patient Weight."},
          {examInfoName + "/" + GEExamInfo.TRAUMA,
	   "Trauma Flag."},
          {examInfoName + "/" + GEExamInfo.PATIENT_HISTORY,
	   "Patient History."},
          {examInfoName + "/" + GEExamInfo.REQ_NUMBER,
	   "Requisition Number."},
          {examInfoName + "/" + GEExamInfo.EXAM_DATE,
	   "Exam date/time stamp."},
          {examInfoName + "/" + GEExamInfo.REF_PHYSICIAN,
	   "Referring Physician."},
          {examInfoName + "/" + GEExamInfo.DIAGRAD,
	   "Diagnostician/Radiologist."},
          {examInfoName + "/" + GEExamInfo.OPERATOR,
	   "Operator."},
          {examInfoName + "/" + GEExamInfo.EXAM_DESCRIPTION,
	   "Exam Description."},
          {examInfoName + "/" + GEExamInfo.EXAM_TYPE,
	   "Exam Type."},
          {examInfoName + "/" + GEExamInfo.EXAM_FORMAT,
	   "Exam Format."},
          {examInfoName + "/" + GEExamInfo.FIRST_AXIAL_TIME,
	   "Start time(secs) of first axial in exam."},
          {examInfoName + "/" + GEExamInfo.HOST,
	   "Creator Suite and Host."},
          {examInfoName + "/" + GEExamInfo.LAST_MOD,
	   "Date/Time of Last Change."},
          {examInfoName + "/" + GEExamInfo.PROTOCOL_FLAG,
	   "Non-Zero indicates Protocol Exam."},
          {examInfoName + "/" + GEExamInfo.ALLOC_KEY,
	   "Process that allocated this record."},
          {examInfoName + "/" + GEExamInfo.UPDATA_CNT,
	   "Indicates number of updates to header."},
          {examInfoName + "/" + GEExamInfo.VERSION_CREATION,
	   "Genesis Version - Created."},
          {examInfoName + "/" + GEExamInfo.VERSION_NOW,
	   "Genesis Version - Now."},
          {examInfoName + "/" + GEExamInfo.CHECK_SUM,
	   "Exam Record Checksum."},
          {examInfoName + "/" + GEExamInfo.COMPLETE_FLAG,
	   "Exam Complete Flag."},
          {examInfoName + "/" + GEExamInfo.SERIES_CNT,
	   "Last Series Number Used."},
          {examInfoName + "/" + GEExamInfo.NUMBER_ARCHIVED,
	   "Number of Series Archived."},
          {examInfoName + "/" + GEExamInfo.NUMBER_SERIES,
	   "Number of Series Existing."},
          {examInfoName + "/" + GEExamInfo.SERIES_KEY_LEN,
	   "Number Series Keys for this Exam."},
          {examInfoName + "/" + GEExamInfo.SERIES_KEY,
	   "Series Keys for this Exam."},
          {examInfoName + "/" + GEExamInfo.NUMBER_UNST_SERIES,
	   "Number Unstored Series for this Exam."},
          {examInfoName + "/" + GEExamInfo.UNST_SERIES_KEY_LEN,
	   "Number of Unstored Series Keys for this Exam."},
          {examInfoName + "/" + GEExamInfo.UNST_SERIES_KEY,
	   "Unstored Series Keys for this Exam."},
          {examInfoName + "/" + GEExamInfo.NUMBER_UNARCH_SERIES,
	   "Number of Unarchived Series for this Exam."},
          {examInfoName + "/" + GEExamInfo.UNARCH_SERIES_KEY_LEN,
	   "Number of Unarchived Series Keys for this Exam."},     
	  {examInfoName + "/" + GEExamInfo.UNARCH_SERIES_KEY,
	   "Unarchived Series Keys for this Exam."},
          {examInfoName + "/" + GEExamInfo.NUMBER_PROS_SERIES,
	   "Number Prospective/Scout Series for this Exam."},
          {examInfoName + "/" + GEExamInfo.PROS_SERIES_KEY_LEN,
	   "Number Prospective/Scout Series Keys for this Exam."},
          {examInfoName + "/" + GEExamInfo.PROS_SERIES_KEY,
	   "Prospective/Scout Series Keys for this Exam."},
          {examInfoName + "/" + GEExamInfo.MODEL_NUMBER,
	   "Last Model Number used."},
          {examInfoName + "/" + GEExamInfo.MODEL_CNT,
	   "Number of ThreeD Models."},
          {examInfoName + "/" + GEExamInfo.MODEL_KEY_LEN,
	   "Number ThreeD Model Keys for Exam."},
          {examInfoName + "/" + GEExamInfo.MODEL_KEY,
	   "ThreeD Model Keys for Exam."},
          {examInfoName + "/" + GEExamInfo.PATIENT_STATUS,
	   "Patient Status."},
          {examInfoName + "/" + GEExamInfo.SYSTEM_ID,
	   "Unique System ID."},
          {examInfoName + "/" + GEExamInfo.SERVICE_ID,
	   "Unique Service ID."},
          {examInfoName + "/" + GEExamInfo.MOBLE_LOCATION,
	   "Mobile Location Number."},
	  
    	  {seriesInfoName + "/" + GESeriesInfo.SUITE_ID,
	   "Suite ID for this Series."},
	  {seriesInfoName + "/" + GESeriesInfo.UNIQUE_FLAG,
	   "Unique Flag."},
	  {seriesInfoName + "/" + GESeriesInfo.DISK_ID,
	   "Disk ID for this Series."},
	  {seriesInfoName + "/" + GESeriesInfo.EXAM_NUMBER,
	   "Exam Number."},
	  {seriesInfoName + "/" + GESeriesInfo.SERIES_NUMBER,
	   "Series Number."},
	  {seriesInfoName + "/" + GESeriesInfo.ALLOC_TIME_STAMP,
	   "Allocation Series Data/Time stamp."},
	  {seriesInfoName + "/" + GESeriesInfo.ACTUAL_TIME_STAMP,
	   "Actual Series Data/Time stamp."},
	  {seriesInfoName + "/" + GESeriesInfo.SERIES_DESCRIPTION,
	   "Series Description."},
	  {seriesInfoName + "/" + GESeriesInfo.PRIMARY_RECIEVER_HOST,
	   "Primary Receiver Suite and Host."},
	  {seriesInfoName + "/" + GESeriesInfo.ARCHIVER_HOST,
	   "Archiver Suite and Host."},
	  {seriesInfoName + "/" + GESeriesInfo.SERIES_TYPE,
	   "Series Type."},     
	  {seriesInfoName + "/" + GESeriesInfo.SERIES_SOURCE,
	   "Series from which prescribed."},
	  {seriesInfoName + "/" + GESeriesInfo.PLANE,
	   "Most-like Plane (for L/S)."},
	  {seriesInfoName + "/" + GESeriesInfo.SCAN_TYPE,
	   "Scout or Axial (for CT)."},
	  {seriesInfoName + "/" + GESeriesInfo.POSITION,
	   "Patient Position."},
	  {seriesInfoName + "/" + GESeriesInfo.ENTRY,
	   "Patient Entry."},
	  {seriesInfoName + "/" + GESeriesInfo.ANATOM_REFERENCE,
	   "Anatomical reference."},
	  {seriesInfoName + "/" + GESeriesInfo.HORIZONTAL_LANDMARK,
	   "Horizontal Landmark."},
	  {seriesInfoName + "/" + GESeriesInfo.PROTOCOL_NAME,
	   "Scan Protocol Name."},
	  {seriesInfoName + "/" + GESeriesInfo.CONTRAST,
	   "Non-zero if > 0 image used contrast(L/S)."},
	  {seriesInfoName + "/" + GESeriesInfo.START_RAS,
	   "RAS letter for first scan location (L/S)."},
	  {seriesInfoName + "/" + GESeriesInfo.START_LOC,
	   "First scan location (L/S)."},
	  {seriesInfoName + "/" + GESeriesInfo.END_RAS,
	   "RAS letter for last scan location (L/S)."},
	  {seriesInfoName + "/" + GESeriesInfo.END_LOC,
	   "Last scan location (L/S)."},
	  {seriesInfoName + "/" + GESeriesInfo.PULSE_SEQUENCE,
	   "Last Pulse Sequence Used (L/S)."},
	  {seriesInfoName + "/" + GESeriesInfo.SORT_ORDER,
	   "Image Sort Order (L/S)."},
	  {seriesInfoName + "/" + GESeriesInfo.LANDMARK_CNTR,
	   "Landmark Counter."},
	  {seriesInfoName + "/" + GESeriesInfo.NUMBER_AQUISITIONS,
	   "Number of Acquisitions."},       
	  {seriesInfoName + "/" + GESeriesInfo.BASELINE_START,
	   "Starting number for baselines."},
	  {seriesInfoName + "/" + GESeriesInfo.BASELINE_END,
	   "Ending number for baselines."},
	  {seriesInfoName + "/" + GESeriesInfo.ENHANCED_START,
	   "Starting number for enhanced scans."},
	  {seriesInfoName + "/" + GESeriesInfo.ENHANCED_END,
	   "Ending number for enhanced scans."},
	  {seriesInfoName + "/" + GESeriesInfo.LAST_MOD,
	   "Date/Time of Last Change."},
	  {seriesInfoName + "/" + GESeriesInfo.ALLOC_KEY,
	   "Process that allocated this record."},
	  {seriesInfoName + "/" + GESeriesInfo.HEADER_UPDATE_CNT,
	   "Indicates number of updates to header."},
	  {seriesInfoName + "/" + GESeriesInfo.VERSION_CREATED,
	   "Genesis Version - Created."},
	  {seriesInfoName + "/" + GESeriesInfo.VERSION_NOW,
	   "Genesis Version - Now."},
	  {seriesInfoName + "/" + GESeriesInfo.STORED_PIXEL_SIZE,
	   "PixelData size - as stored."},
	   
	  {seriesInfoName + "/" + GESeriesInfo.COMP_PIXEL_DATA_SIZE,
	   "PixelData size - Compressed."},
	  {seriesInfoName + "/" + GESeriesInfo.UNCOMP_PIXEL_DATA_SIZE,
	   "PixelData size - UnCompressed."},
	  {seriesInfoName + "/" + GESeriesInfo.CHECK_SUM,
	   "Series Record checksum."},
	  {seriesInfoName + "/" + GESeriesInfo.COMPLETE,
	   "Series Complete Flag."},
	  {seriesInfoName + "/" + GESeriesInfo.NUM_ARCHIVED,
	   "Number of Images Archived."},
	  {seriesInfoName + "/" + GESeriesInfo.LAST_IMAGE,
	   "Last Image Number Used."},
	  {seriesInfoName + "/" + GESeriesInfo.NUMBER_IMAGES,
	   "Number of Images Existing."},
	  {seriesInfoName + "/" + GESeriesInfo.IMAGE_KEY_LEN,
	   "Size of Image Key for this Series."},
	  {seriesInfoName + "/" + GESeriesInfo.IMAGE_KEY,
	   "Image Keys for this Series."},
	  {seriesInfoName + "/" + GESeriesInfo.NUMBER_UNST_IMAGES,
	   "Number of Unstored Images."},
	  {seriesInfoName + "/" + GESeriesInfo.UNST_IMAGE_KEY_LEN,
	   "Size of Unstored Image Keys for this Series."},
	  {seriesInfoName + "/" + GESeriesInfo.UNST_IMAGE_KEY,
	   "Unstored Image Keys for this Series."},
	  {seriesInfoName + "/" + GESeriesInfo.NUMBER_UNARCH_IMAGES,
	   "Number of Unarchived Images."},
	  {seriesInfoName + "/" + GESeriesInfo.UNARCH_IMAGE_KEY_LEN,
	   "Size of Unarchived Image Keys for this Series."},
	  {seriesInfoName + "/" + GESeriesInfo.UNARCH_IAMGE_KEY,
	   "Unarchived Image Keys for this Series."},
	  {seriesInfoName + "/" + GESeriesInfo.ECHO1_ALPHA,
	   "Echo 1 Alpha Value."},
	  {seriesInfoName + "/" + GESeriesInfo.ECHO1_BETA,
	   "Echo 1 Beta Value."},
	  {seriesInfoName + "/" + GESeriesInfo.ECHO1_WINDOW,
	   "Echo 1 Window Value."},
	  {seriesInfoName + "/" + GESeriesInfo.ECHO1_LEVEL,
	   "Echo 1 Level Value."},
	  {seriesInfoName + "/" + GESeriesInfo.ECHO2_ALPHA,
	   "Echo 2 Alpha Value."},
	  {seriesInfoName + "/" + GESeriesInfo.ECHO2_BETA,
	   "Echo 2 Beta Value."},
	  {seriesInfoName + "/" + GESeriesInfo.ECHO2_WINDOW,
	   "Echo 2 Window Value."},
	  {seriesInfoName + "/" + GESeriesInfo.ECHO2_LEVEL,
	   "Echo 2 Level Value."},
	  {seriesInfoName + "/" + GESeriesInfo.ECHO3_ALPHA,
	   "Echo 3 Alpha Value."},
	  {seriesInfoName + "/" + GESeriesInfo.ECHO3_BETA,
	   "Echo 3 Beta Value."},
	  {seriesInfoName + "/" + GESeriesInfo.ECHO3_WINDOW,
	   "Echo 3 Window Value."},
	  {seriesInfoName + "/" + GESeriesInfo.ECHO3_LEVEL,
	   "Echo 3 Level Value."},
	  {seriesInfoName + "/" + GESeriesInfo.ECHO4_ALPHA,
	   "Echo 4 Alpha Value."},
	  {seriesInfoName + "/" + GESeriesInfo.ECHO4_BETA,
	   "Echo 4 Beta Value."},
	  {seriesInfoName + "/" + GESeriesInfo.ECHO4_WINDOW,
	   "Echo 4 Window Value."},
	  {seriesInfoName + "/" + GESeriesInfo.ECHO4_LEVEL,
	   "Echo 4 Level Value."},
	  {seriesInfoName + "/" + GESeriesInfo.ECHO5_ALPHA,
	   "Echo 5 Alpha Value."},
	  {seriesInfoName + "/" + GESeriesInfo.ECHO5_BETA,
	   "Echo 5 Beta Value."},
	  {seriesInfoName + "/" + GESeriesInfo.ECHO5_WINDOW,
	   "Echo 5 Window Value."},
	  {seriesInfoName + "/" + GESeriesInfo.ECHO5_LEVEL,
	   "Echo 5 Level Value."},
	  {seriesInfoName + "/" + GESeriesInfo.ECHO6_ALPHA,
	   "Echo 6 Alpha Value."},
	  {seriesInfoName + "/" + GESeriesInfo.ECHO6_BETA,
	   "Echo 6 Beta Value."},
	  {seriesInfoName + "/" + GESeriesInfo.ECHO6_WINDOW,
	   "Echo 6 Window Value."},
	  {seriesInfoName + "/" + GESeriesInfo.ECHO6_LEVEL,
	   "Echo 6 Level Value."},
	  {seriesInfoName + "/" + GESeriesInfo.ECHO7_ALPHA,
	   "Echo 7 Alpha Value."},
	  {seriesInfoName + "/" + GESeriesInfo.ECHO7_BETA,
	   "Echo 7 Beta Value."},
	  {seriesInfoName + "/" + GESeriesInfo.ECHO7_WINDOW,
	   "Echo 7 Window Value."},
	  {seriesInfoName + "/" + GESeriesInfo.ECHO7_LEVEL,
	   "Echo 7 Level Value."},
	  {seriesInfoName + "/" + GESeriesInfo.ECHO8_ALPHA,
	   "Echo 8 Alpha Value."},
	  {seriesInfoName + "/" + GESeriesInfo.ECHO8_BETA,
	   "Echo 8 Beta Value."},
	  {seriesInfoName + "/" + GESeriesInfo.ECHO8_WINDOW,
	   "Echo 8 Window Value."},
	  {seriesInfoName + "/" + GESeriesInfo.ECHO8_LEVEL,
	   "Echo 8 Level Value."},
	  
	  
	  {mrImageInfoName + "/" + GEImageInfo.SUITE_ID,
	   "suite ID for this image."},
	  {mrImageInfoName + "/" + GEImageInfo.UNIQUE_FLAG,
	   "Unique Flag."},
	  {mrImageInfoName + "/" + GEImageInfo.DISK_ID,
	   "Disk ID for this Image."},
	  {mrImageInfoName + "/" + GEImageInfo.EXAM_NUMBER,
	   "Exam number for this image."},
	  {mrImageInfoName + "/" + GEImageInfo.SERIES_NUM,
	   "Series Number for this image."},
	  {mrImageInfoName + "/" + GEImageInfo.IMAGE_NUM,
	   "Image Number."},
	  {mrImageInfoName + "/" + GEImageInfo.ALLOC_DATE_TIME,
	   "Allocation Image date/time stamp."},
	  {mrImageInfoName + "/" + GEImageInfo.ACTUAL_DATE_TIME,
	   "Actual Image date/time stamp."},
	  {mrImageInfoName + "/" + GEImageInfo.SCAN_TIME,
	   "Duration of scan (secs)."},
	  {mrImageInfoName + "/" + GEImageInfo.SLICE_THICK,
	   "Slice Thickness (mm)."},
	  {mrImageInfoName + "/" + GEImageInfo.I_MATRIX_X,
	   "Image matrix size - X."},
	  {mrImageInfoName + "/" + GEImageInfo.I_MATRIX_Y,
	   "Image matrix size - Y."},
	  {mrImageInfoName + "/" + GEImageInfo.DISPLAY_FIELD_X,
	   "Display field of view - X (mm)."},
	  {mrImageInfoName + "/" + GEImageInfo.DISPLAY_FIELD_Y,
	   "Display field of view - Y (if different)."},
	  {mrImageInfoName + "/" + GEImageInfo.DIMENSION_X,
	   "Image dimension - X."},
	  {mrImageInfoName + "/" + GEImageInfo.DIMENSION_Y,
	   "Image dimension - Y."},
	  {mrImageInfoName + "/" + GEImageInfo.PIXEL_SIZE_X,
	   "Image pixel size - X."},
	  {mrImageInfoName + "/" + GEImageInfo.PIXEL_SIZE_Y,
	   "Image pixel size - Y."},
	  {mrImageInfoName + "/" + GEImageInfo.PIXEL_DATA_ID,
	   "Pixel Data ID."},
	  {mrImageInfoName + "/" + GEImageInfo.CONTRAST_IV,
	   "IV Contrast Agent."},
	  {mrImageInfoName + "/" + GEImageInfo.CONTRAST_ORAL,
	   "Oral Contrast Agent."},
	  {mrImageInfoName + "/" + GEImageInfo.CONTRAST_MODE,
	   "Image Contrast Mode."},
	  {mrImageInfoName + "/" + GEImageInfo.SERIES_RX,
	   "Series from which prescribed."},
	  {mrImageInfoName + "/" + GEImageInfo.IMAGE_RX,
	   "Image from which prescribe."},
	  {mrImageInfoName + "/" + GEImageInfo.SCREEN_FORMAT,
	   "Screen Format(8/16 bit)."},
	  {mrImageInfoName + "/" + GEImageInfo.PLANE,
	   "Plane Type."},
	  {mrImageInfoName + "/" + GEImageInfo.SCAN_SPACING,
	   "Spacing between scans (mm?)."},
	  {mrImageInfoName + "/" + GEImageInfo.COMPRESSION,
	   "Image compression type for allocation."},
	  {mrImageInfoName + "/" + GEImageInfo.SCOUT_TYPE,
	   "Scout Type (AP or lateral)."},
	  {mrImageInfoName + "/" + GEImageInfo.LOCATION_RAS,
	   "RAS letter of image location."},
	  {mrImageInfoName + "/" + GEImageInfo.IMAGE_LOCATION,
	   "Image location."},
	  {mrImageInfoName + "/" + GEImageInfo.CENTER_R,
	   "Center R coord of plane image."},
	  {mrImageInfoName + "/" + GEImageInfo.CENTER_A,
	   "Center A coord of plane image."},
	  {mrImageInfoName + "/" + GEImageInfo.CENTER_S,
	   "Center S coord of plane image."},
	  {mrImageInfoName + "/" + GEImageInfo.NORM_R,
	   "Normal R coord."},
	  {mrImageInfoName + "/" + GEImageInfo.NORM_A,
	   "Normal A coord."},
	  {mrImageInfoName + "/" + GEImageInfo.NORM_S ,
	   "Normal S coord."},    
	  {mrImageInfoName + "/" + GEImageInfo.TOP_LEFT_R,
	   "R Coord of Top Left Hand Corner."},
	  {mrImageInfoName + "/" + GEImageInfo.TOP_LEFT_A,
	   "A Coord of Top Left Hand Corner."},
	  {mrImageInfoName + "/" + GEImageInfo.TOP_LEFT_S,
	   "S Coord of Top Left Hand Corner."},
	  {mrImageInfoName + "/" + GEImageInfo.TOP_RIGHT_R,
	   "R Coord of Top Right Hand Corner."},
	  {mrImageInfoName + "/" + GEImageInfo.TOP_RIGHT_A,
	   "A Coord of Top Right Hand Corner."},
	  {mrImageInfoName + "/" + GEImageInfo.TOP_RIGHT_S,
	   "S Coord of Top Right Hand Corner."},
	  {mrImageInfoName + "/" + GEImageInfo.BOT_RIGHT_R,
	   "R Coord of Bottom Right Hand Corner."},
	  {mrImageInfoName + "/" + GEImageInfo.BOT_RIGHT_A,
	   "A Coord of Bottom Right Hand Corner."},
	  {mrImageInfoName + "/" + GEImageInfo.BOT_RIGHT_S,
	   "S Coord of Bottom Right Hand Corner."},
	  {mrImageInfoName + "/" + GEImageInfo.FOREIGN_IMAGE_REV,
	   "Foreign Image Revision."},
	  {mrImageInfoName + "/" + GEImageInfo.ALLOC_KEY,
	  "Allocation Key."},
	  {mrImageInfoName + "/" + GEImageInfo.LAST_MOD,
	  "Date/Time of Last Change."},
	  {mrImageInfoName + "/" + GEImageInfo.VERSION_CREATION,
	  "Genesis Version - Created."},
	  {mrImageInfoName + "/" + GEImageInfo.VERSION_NOW,
	  "Genesis Version - Now."},
	  {mrImageInfoName + "/" + GEImageInfo.PIXEL_DATA_SIZE_A,
	  "PixelData size - as stored."},
	  {mrImageInfoName + "/" + GEImageInfo.PIXEL_DATA_SIZE_C,
	  "PixelData size - Compressed."},
	  {mrImageInfoName + "/" + GEImageInfo.PIXEL_DATA_SIZE_U,
	  "PixelData size - UnCompressed."},
	  {mrImageInfoName + "/" + GEImageInfo.CHECK_SUM,
	  "AcqRecon record checksum."},
	  {mrImageInfoName + "/" + GEImageInfo.ARCHIVE,
	  "Image Archive Flag."},
	  {mrImageInfoName + "/" + GEImageInfo.COMPLETE,
	  "Image Complete Flag."},
	  {mrImageInfoName + "/" + GEImageInfo.REFERENCE_FIELD,
	  "Reference Image Field."},
	  {mrImageInfoName + "/" + GEImageInfo.SUMMARY_FIELD,
	  "Summary Image Field."},
	  {mrImageInfoName + "/" + GEImageInfo.WINDOW,
	  "Window Value."},
	  {mrImageInfoName + "/" + GEImageInfo.LEVEL,
	  "Level Value."},
	  {mrImageInfoName + "/" + GEImageInfo.SLOP_INT1,
	  "Integer Slop Field 1."},
	  {mrImageInfoName + "/" + GEImageInfo.SLOP_INT2,
	  "Integer Slop Field 2."},
	  {mrImageInfoName + "/" + GEImageInfo.SLOP_INT3,
	  "Integer Slop Field 3."},
	  {mrImageInfoName + "/" + GEImageInfo.SLOP_INT4,
	  "Integer Slop Field 4."},
	  {mrImageInfoName + "/" + GEImageInfo.SLOP_INT5,
	  "Integer Slop Field 5."}, 
	  {mrImageInfoName + "/" + GEImageInfo.SLOP_FLOAT1,
	  "Float Slop Field 1."},
	  {mrImageInfoName + "/" + GEImageInfo.SLOP_FLOAT2,
	  "Float Slop Field 1."},
	  {mrImageInfoName + "/" + GEImageInfo.SLOP_FLOAT3,
	  "Float Slop Field 1."},
	  {mrImageInfoName + "/" + GEImageInfo.SLOP_FLOAT4,
	  "Float Slop Field 1."},
	  {mrImageInfoName + "/" + GEImageInfo.SLOP_FLOAT5,
	  "Float Slop Field 1."},
	  {mrImageInfoName + "/" + GEImageInfo.SLOP_STR1,
	   "String Slop Field 1."},
	  {mrImageInfoName + "/" + GEImageInfo.SLOP_STR2,
	   "String Slop Field 2."},

	  {mrImageInfoName + "/" + GEMRImageInfo.REP_TIME,
	   "Pulse repetition time(usec)."},
	  {mrImageInfoName + "/" + GEMRImageInfo.INV_TIME,
	   "Pulse inversion time(usec)."},
	  {mrImageInfoName + "/" + GEMRImageInfo.ECHO_TIME,
	   "Pulse echo time(usec)."},
	  {mrImageInfoName + "/" + GEMRImageInfo.ECHO_TIME2,
	   "Second echo echo (usec)."},
	  {mrImageInfoName + "/" + GEMRImageInfo.NUM_ECHO,
	   "Number of echoes."},
	  {mrImageInfoName + "/" + GEMRImageInfo.ECHO_NUMBER,
	   "Echo Number."},
	  {mrImageInfoName + "/" + GEMRImageInfo.TABLE_DELTA,
	   "Table Delta."},
	  {mrImageInfoName + "/" + GEMRImageInfo.NUM_EXCITATIONS,
	   "Number of Excitations."},
	  {mrImageInfoName + "/" + GEMRImageInfo.CONTINUOUS,
	   "Continuous Slices Flag."},
	  {mrImageInfoName + "/" + GEMRImageInfo.HEART_RATE,
	  "Cardiac Heart Rate (bpm)."},
	  {mrImageInfoName + "/" + GEMRImageInfo.TIME_DELAY,
	  "Delay time after trigger (usec)."},
	  {mrImageInfoName + "/" + GEMRImageInfo.AVERAGE_SAR,
	  "Average SAR."},
	  {mrImageInfoName + "/" + GEMRImageInfo.PEAK_SAR,
	  "Peak SAR."},
	  {mrImageInfoName + "/" + GEMRImageInfo.MONITOR_SAR,
	  "Monitor SAR flag."},
	  {mrImageInfoName + "/" + GEMRImageInfo.TRIGGER_WINDOW,
	  "Trigger window (% of R-R interval)."},
	  {mrImageInfoName + "/" + GEMRImageInfo.CARD_REP_TIME,
	  "Cardiac repetition time."},
	  {mrImageInfoName + "/" + GEMRImageInfo.IMAGES_PER_CYCLE,
	  "Images per cardiac cycle."},
	  {mrImageInfoName + "/" + GEMRImageInfo.TRANSMIT_GAIN,
	  "Actual Transmit Gain (.1 db)."},
	  {mrImageInfoName + "/" + GEMRImageInfo.RECV_GAIN_ANALOG,
	  "Actual Receive Gain Analog (.1 db)."},
	  {mrImageInfoName + "/" + GEMRImageInfo.RECV_GAIN_DIGITAL,
	  "Actual Receive Gain Digital (.1 db)."},
	  {mrImageInfoName + "/" + GEMRImageInfo.FLIP_ANGLE,
	  "Flip Angle for GRASS scans (deg.)."},
	  {mrImageInfoName + "/" + GEMRImageInfo.MIN_DELAY,
	  "Minimum Delay after Trigger (uSec)."},
	  {mrImageInfoName + "/" + GEMRImageInfo.CARDIAC_PHASE,
	  "Total Cardiac Phase prescribed."},
	  {mrImageInfoName + "/" + GEMRImageInfo.SWAP_PHASE_FREQ,
	  "Swap Phase/Frequency Axis."},    
	  {mrImageInfoName + "/" + GEMRImageInfo.PAUSE_INTERVAL,
	  "Pause Interval (slices)."},
	  {mrImageInfoName + "/" + GEMRImageInfo.PAUSE_TIME,
	  "Pause Time."}, 
	  {mrImageInfoName + "/" + GEMRImageInfo.OBLIQUE_PLANE,
	  "Oblique Plane."},
	  {mrImageInfoName + "/" + GEMRImageInfo.SLICE_OFF,
	  "Slice Offsets on Freq axis."},
	  {mrImageInfoName + "/" + GEMRImageInfo.TRANSMIT_FREQ,
	  "Center Frequency (0.1 Hz)."},
	  {mrImageInfoName + "/" + GEMRImageInfo.AUTO_CENTER_FREQ,
	  "Auto Center Frequency (0.1 Hz)."},
	  {mrImageInfoName + "/" + GEMRImageInfo.AUTO_TRANS_GAIN,
	  "Auto Transmit Gain (0.1 dB)."},
	  {mrImageInfoName + "/" + GEMRImageInfo.PRESCAN_R1_ANALOG,
	  "PreScan R1 - Analog."},
	  {mrImageInfoName + "/" + GEMRImageInfo.PRESCAN_R2_DIGITAL,
	  "PreScan R2 - Digital."},
	  {mrImageInfoName + "/" + GEMRImageInfo.USER_BITMAP,
	  "Bitmap defining user CVs."},
	  {mrImageInfoName + "/" + GEMRImageInfo.CENTER_FREQ,
	  "Center Frequency Method."},
	  {mrImageInfoName + "/" + GEMRImageInfo.IMAGEING_MODE,
	  "Imaging Mode."},
	  {mrImageInfoName + "/" + GEMRImageInfo.IMAGEING_OPTIONS,
	  "Imaging Options."},
	  {mrImageInfoName + "/" + GEMRImageInfo.PULSE_SEQ,
	  "Pulse Sequence."},
	  {mrImageInfoName + "/" + GEMRImageInfo.PULSE_SEQ_MODE,
	  "Pulse Sequence Mode."},
	  {mrImageInfoName + "/" + GEMRImageInfo.PULSE_SEQ_NAME,
	  "Pulse Sequence Name."},
	  {mrImageInfoName + "/" + GEMRImageInfo.PSD_DATE_TIME,
	  "PSD Creation Date and Time."},
	  {mrImageInfoName + "/" + GEMRImageInfo.PSD_NAME,
	  "PSD name from inside PSD."},
	  {mrImageInfoName + "/" + GEMRImageInfo.COIL_TYPE,
	  "Coil Type."},
          {mrImageInfoName + "/" + GEMRImageInfo.COIL_NAME,
	  "Coil Name."},
	  {mrImageInfoName + "/" + GEMRImageInfo.SRF_COIL_TYPE,
	  "Surface Coil Type."},
	  {mrImageInfoName + "/" + GEMRImageInfo.SRF_COIL_EXTR,
	  "Extremity Coil Flag."},
	  {mrImageInfoName + "/" + GEMRImageInfo.RAW_RUN_NUMBER,
	  "RawData Run Number."},
	  {mrImageInfoName + "/" + GEMRImageInfo.CAL_FIELD_STRENGTH,
	  "Calibrated Field Strength (x10 uGauss)."},
	  {mrImageInfoName + "/" + GEMRImageInfo.SUPP_TECH,
	  "SAT fat/water/none."},
	  {mrImageInfoName + "/" + GEMRImageInfo.VAR_BANDWIDTH,
	  "Variable Bandwidth (Hz)."},
	  {mrImageInfoName + "/" + GEMRImageInfo.NUM_SLICE_IN_SCAN,
	  "Number of slices in this scan group."},
	  {mrImageInfoName + "/" + GEMRImageInfo.GRAPHIC_PRESCRIBED,
	  "Graphically prescribed."},
	  {mrImageInfoName + "/" + GEMRImageInfo.INTER_DELAY,
	  "Interimage/interloc delay (uSec)."},
	  {mrImageInfoName + "/" + GEMRImageInfo.USER0,
	  "User Variable 0."},
	  {mrImageInfoName + "/" + GEMRImageInfo.USER1
	  ,"User Variable 1."},
	  {mrImageInfoName + "/" + GEMRImageInfo.USER2,
	  "User Variable 2."},
	  {mrImageInfoName + "/" + GEMRImageInfo.USER3,
	  "User Variable 3."},
	  {mrImageInfoName + "/" + GEMRImageInfo.USER4,
	  "User Variable 4."},
	  {mrImageInfoName + "/" + GEMRImageInfo.USER5,
	  "User Variable 5."},
	  {mrImageInfoName + "/" + GEMRImageInfo.USER6,
	  "User Variable 6."},
	  {mrImageInfoName + "/" + GEMRImageInfo.USER7,
	  "User Variable 7."},
	  {mrImageInfoName + "/" + GEMRImageInfo.USER8,
	  "User Variable 8."},
	  {mrImageInfoName + "/" + GEMRImageInfo.USER9,
	  "User Variable 9."},
          {mrImageInfoName + "/" + GEMRImageInfo.USER10,
	  "User Variable 10."},
	  {mrImageInfoName + "/" + GEMRImageInfo.USER11,
	  "User Variable 11."},
	  {mrImageInfoName + "/" + GEMRImageInfo.USER12,
	  "User Variable 12."},
	  {mrImageInfoName + "/" + GEMRImageInfo.USER13,
	  "User Variable 13."},
	  {mrImageInfoName + "/" + GEMRImageInfo.USER14,
	  "User Variable 14."},
	  {mrImageInfoName + "/" + GEMRImageInfo.USER15,
	  "User Variable 15."},
	  {mrImageInfoName + "/" + GEMRImageInfo.USER16,
	  "User Variable 16."},
	  {mrImageInfoName + "/" + GEMRImageInfo.USER17,
	  "User Variable 17."},
	  {mrImageInfoName + "/" + GEMRImageInfo.USER18,
	  "User Variable 18."},
	  {mrImageInfoName + "/" + GEMRImageInfo.USER19,
	  "User Variable 19."},
	  {mrImageInfoName + "/" + GEMRImageInfo.USER20,
	  "User Variable 20."},
	  {mrImageInfoName + "/" + GEMRImageInfo.USER21,
	  "User Variable 21."},
	  {mrImageInfoName + "/" + GEMRImageInfo.USER22,
	  "User Variable 22."},
	  {mrImageInfoName + "/" + GEMRImageInfo.PROJ_ANGLE,
	  "Projection Angle."},
	  {mrImageInfoName + "/" + GEMRImageInfo.SAT_TYPE,
	  "Concat Sat Type Flag."},
	  {mrImageInfoName + "/" + GEMRImageInfo.SAT_BITS,
	  "Bitmap of SAT selections."},
	  {mrImageInfoName + "/" + GEMRImageInfo.SRF_COIL_INTENSITY,
	  "Surface Coil Intensity Correction Flag."},
	  {mrImageInfoName + "/" + GEMRImageInfo.SAT_X_LOC_R,
	  "R-side SAT pulse loc rel to lndmrk."},
	  {mrImageInfoName + "/" + GEMRImageInfo.SAT_X_LOC_L,
	  "L-side SAT pulse loc rel to lndmrk."},
	  {mrImageInfoName + "/" + GEMRImageInfo.SAT_Y_LOC_A,
	  "A-side SAT pulse loc rel to lndmrk."},
	  {mrImageInfoName + "/" + GEMRImageInfo.SAT_Y_LOC_P,
	  "P-side SAT pulse loc rel to lndmrk."},
	  {mrImageInfoName + "/" + GEMRImageInfo.SAT_Z_LOC_S,
	  "S-side SAT pulse loc rel to lndmrk."},
	  {mrImageInfoName + "/" + GEMRImageInfo.SAT_Z_LOC_I,
	  "I-side SAT pulse loc rel to lndmrk."},
	  {mrImageInfoName + "/" + GEMRImageInfo.SAT_X_THICK,
	  "Thickness of X-axis SAT pulse."},
	  {mrImageInfoName + "/" + GEMRImageInfo.SAT_Y_THICK,
	  "Thickness of Y-axis SAT pulse."},
	  {mrImageInfoName + "/" + GEMRImageInfo.SAT_Z_THICK,
	  "Thickness of Z-axis SAT pulse."},
	  {mrImageInfoName + "/" + GEMRImageInfo.FLOW_AXIS_CONTRAST,
	  "Phase contrast flow axis."},
	  {mrImageInfoName + "/" + GEMRImageInfo.VELOCITY_CONTRAST,
	  "Phase contrast velocity encoding."},
	  {mrImageInfoName + "/" + GEMRImageInfo.THICK_DISCLAIMER,
	  "Slice Thickness."},
	  {mrImageInfoName + "/" + GEMRImageInfo.PRESCAN_FLAG,
	  "Auto/Manual Prescan flag."},
	  {mrImageInfoName + "/" + GEMRImageInfo.CHANGE_BITMAP,
	  "Bitmap of changed values."},
	  {mrImageInfoName + "/" + GEMRImageInfo.IMAGE_TYPE,
	  "Magnitude, Phase, Imaginary, or Real."},
	  {mrImageInfoName + "/" + GEMRImageInfo.COLLAPSE,
	  "Collapse Image."},
	  {mrImageInfoName + "/" + GEMRImageInfo.USER23,
	  "User Variable 23."},
	  {mrImageInfoName + "/" + GEMRImageInfo.USER24,
	  "User Variable 24."},
	  {mrImageInfoName + "/" + GEMRImageInfo.PROJECTION_ALG,
	  "Projection Algorithm."},
	  {mrImageInfoName + "/" + GEMRImageInfo.PROJECTION_NAME,
	  "Projection Algorithm Name."},
	  {mrImageInfoName + "/" + GEMRImageInfo.X_AXIS_ROT,
	  "X Axis Rotation."},
	  {mrImageInfoName + "/" + GEMRImageInfo.Y_AXIS_ROT,
	  "Y Axis Rotation."},
	  {mrImageInfoName + "/" + GEMRImageInfo.Z_AXIS_ROT,
	  "Z Axis Rotation."},
	  {mrImageInfoName + "/" + GEMRImageInfo.MIN_PIXEL1,
	  "Lower Range of Pixels 1."},
	  {mrImageInfoName + "/" + GEMRImageInfo.MAX_PIXEL1,
	  "Upper Range of Pixels 1."},
	  {mrImageInfoName + "/" + GEMRImageInfo.MIN_PIXEL2,
	  "Lower Range of Pixels 2."},
            {mrImageInfoName + "/" + GEMRImageInfo.MAX_PIXEL2,
	  "Upper Range of Pixels 2."},
	  {mrImageInfoName + "/" + GEMRImageInfo.ECHO_TRAIN_LEN,
	  "Echo Train Length for Fast Spin Echo."},
	  {mrImageInfoName + "/" + GEMRImageInfo.FRACTION_ECHO,
	  "Fractional Echo - Effective TE Flag."},
	  {mrImageInfoName + "/" + GEMRImageInfo.PREP_PULSE,
	  "Preporatory Pulse Option."},
	  {mrImageInfoName + "/" + GEMRImageInfo.CARDIAC_PHASE_NUM,
	  "Cardiac Phase Number."},
	  {mrImageInfoName + "/" + GEMRImageInfo.VARIABLE_ECHO,
	   "Variable Echo Flag."},

	  {ctImageInfoName + "/" + GEImageInfo.SUITE_ID,
	   "suite ID for this image."},
	  {ctImageInfoName + "/" + GEImageInfo.UNIQUE_FLAG,
	   "Unique Flag."},
	  {ctImageInfoName + "/" + GEImageInfo.DISK_ID,
	   "Disk ID for this Image."},
	  {ctImageInfoName + "/" + GEImageInfo.EXAM_NUMBER,
	   "Exam number for this image."},
	  {ctImageInfoName + "/" + GEImageInfo.SERIES_NUM,
	   "Series Number for this image."},
	  {ctImageInfoName + "/" + GEImageInfo.IMAGE_NUM,
	   "Image Number."},
	  {ctImageInfoName + "/" + GEImageInfo.ALLOC_DATE_TIME,
	   "Allocation Image date/time stamp."},
	  {ctImageInfoName + "/" + GEImageInfo.ACTUAL_DATE_TIME,
	   "Actual Image date/time stamp."},
	  {ctImageInfoName + "/" + GEImageInfo.SCAN_TIME,
	   "Duration of scan (secs)."},
	  {ctImageInfoName + "/" + GEImageInfo.SLICE_THICK,
	   "Slice Thickness (mm)."},
	  {ctImageInfoName + "/" + GEImageInfo.I_MATRIX_X,
	   "Image matrix size - X."},
	  {ctImageInfoName + "/" + GEImageInfo.I_MATRIX_Y,
	   "Image matrix size - Y."},
	  {ctImageInfoName + "/" + GEImageInfo.DISPLAY_FIELD_X,
	   "Display field of view - X (mm)."},
	  {ctImageInfoName + "/" + GEImageInfo.DISPLAY_FIELD_Y,
	   "Display field of view - Y (if different)."},
	  {ctImageInfoName + "/" + GEImageInfo.DIMENSION_X,
	   "Image dimension - X."},
	  {ctImageInfoName + "/" + GEImageInfo.DIMENSION_Y,
	   "Image dimension - Y."},
	  {ctImageInfoName + "/" + GEImageInfo.PIXEL_SIZE_X,
	   "Image pixel size - X."},
	  {ctImageInfoName + "/" + GEImageInfo.PIXEL_SIZE_Y,
	   "Image pixel size - Y."},
	  {ctImageInfoName + "/" + GEImageInfo.PIXEL_DATA_ID,
	   "Pixel Data ID."},
	  {ctImageInfoName + "/" + GEImageInfo.CONTRAST_IV,
	   "IV Contrast Agent."},
	  {ctImageInfoName + "/" + GEImageInfo.CONTRAST_ORAL,
	   "Oral Contrast Agent."},
	  {ctImageInfoName + "/" + GEImageInfo.CONTRAST_MODE,
	   "Image Contrast Mode."},
	  {ctImageInfoName + "/" + GEImageInfo.SERIES_RX,
	   "Series from which prescribed."},
	  {ctImageInfoName + "/" + GEImageInfo.IMAGE_RX,
	   "Image from which prescribe."},
	  {ctImageInfoName + "/" + GEImageInfo.SCREEN_FORMAT,
	   "Screen Format(8/16 bit)."},
	  {ctImageInfoName + "/" + GEImageInfo.PLANE,
	   "Plane Type."},
	  {ctImageInfoName + "/" + GEImageInfo.SCAN_SPACING,
	   "Spacing between scans (mm?)."},
	  {ctImageInfoName + "/" + GEImageInfo.COMPRESSION,
	   "Image compression type for allocation."},
	  {ctImageInfoName + "/" + GEImageInfo.SCOUT_TYPE,
	   "Scout Type (AP or lateral)."},
	  {ctImageInfoName + "/" + GEImageInfo.LOCATION_RAS,
	   "RAS letter of image location."},
	  {ctImageInfoName + "/" + GEImageInfo.IMAGE_LOCATION,
	   "Image location."},
	  {ctImageInfoName + "/" + GEImageInfo.CENTER_R,
	   "Center R coord of plane image."},
	  {ctImageInfoName + "/" + GEImageInfo.CENTER_A,
	   "Center A coord of plane image."},
	  {ctImageInfoName + "/" + GEImageInfo.CENTER_S,
	   "Center S coord of plane image."},
	  {ctImageInfoName + "/" + GEImageInfo.NORM_R,
	   "Normal R coord."},
	  {ctImageInfoName + "/" + GEImageInfo.NORM_A,
	   "Normal A coord."},
	  {ctImageInfoName + "/" + GEImageInfo.NORM_S ,
	   "Normal S coord."},    
	  {ctImageInfoName + "/" + GEImageInfo.TOP_LEFT_R,
	   "R Coord of Top Left Hand Corner."},
	  {ctImageInfoName + "/" + GEImageInfo.TOP_LEFT_A,
	   "A Coord of Top Left Hand Corner."},
	  {ctImageInfoName + "/" + GEImageInfo.TOP_LEFT_S,
	   "S Coord of Top Left Hand Corner."},
	  {ctImageInfoName + "/" + GEImageInfo.TOP_RIGHT_R,
	   "R Coord of Top Right Hand Corner."},
	  {ctImageInfoName + "/" + GEImageInfo.TOP_RIGHT_A,
	   "A Coord of Top Right Hand Corner."},
	  {ctImageInfoName + "/" + GEImageInfo.TOP_RIGHT_S,
	   "S Coord of Top Right Hand Corner."},
	  {ctImageInfoName + "/" + GEImageInfo.BOT_RIGHT_R,
	   "R Coord of Bottom Right Hand Corner."},
	  {ctImageInfoName + "/" + GEImageInfo.BOT_RIGHT_A,
	   "A Coord of Bottom Right Hand Corner."},
	  {ctImageInfoName + "/" + GEImageInfo.BOT_RIGHT_S,
	   "S Coord of Bottom Right Hand Corner."},
	  {ctImageInfoName + "/" + GEImageInfo.FOREIGN_IMAGE_REV,
	   "Foreign Image Revision."},
	  {ctImageInfoName + "/" + GEImageInfo.ALLOC_KEY,
	  "Allocation Key."},
	  {ctImageInfoName + "/" + GEImageInfo.LAST_MOD,
	  "Date/Time of Last Change."},
	  {ctImageInfoName + "/" + GEImageInfo.VERSION_CREATION,
	  "Genesis Version - Created."},
	  {ctImageInfoName + "/" + GEImageInfo.VERSION_NOW,
	  "Genesis Version - Now."},
	  {ctImageInfoName + "/" + GEImageInfo.PIXEL_DATA_SIZE_A,
	  "PixelData size - as stored."},
	  {ctImageInfoName + "/" + GEImageInfo.PIXEL_DATA_SIZE_C,
	  "PixelData size - Compressed."},
	  {ctImageInfoName + "/" + GEImageInfo.PIXEL_DATA_SIZE_U,
	  "PixelData size - UnCompressed."},
	  {ctImageInfoName + "/" + GEImageInfo.CHECK_SUM,
	  "AcqRecon record checksum."},
	  {ctImageInfoName + "/" + GEImageInfo.ARCHIVE,
	  "Image Archive Flag."},
	  {ctImageInfoName + "/" + GEImageInfo.COMPLETE,
	  "Image Complete Flag."},
	  {ctImageInfoName + "/" + GEImageInfo.REFERENCE_FIELD,
	  "Reference Image Field."},
	  {ctImageInfoName + "/" + GEImageInfo.SUMMARY_FIELD,
	  "Summary Image Field."},
	  {ctImageInfoName + "/" + GEImageInfo.WINDOW,
	  "Window Value."},
	  {ctImageInfoName + "/" + GEImageInfo.LEVEL,
	  "Level Value."},
	  {ctImageInfoName + "/" + GEImageInfo.SLOP_INT1,
	  "Integer Slop Field 1."},
	  {ctImageInfoName + "/" + GEImageInfo.SLOP_INT2,
	  "Integer Slop Field 2."},
	  {ctImageInfoName + "/" + GEImageInfo.SLOP_INT3,
	  "Integer Slop Field 3."},
	  {ctImageInfoName + "/" + GEImageInfo.SLOP_INT4,
	  "Integer Slop Field 4."},
	  {ctImageInfoName + "/" + GEImageInfo.SLOP_INT5,
	  "Integer Slop Field 5."}, 
	  {ctImageInfoName + "/" + GEImageInfo.SLOP_FLOAT1,
	  "Float Slop Field 1."},
	  {ctImageInfoName + "/" + GEImageInfo.SLOP_FLOAT2,
	  "Float Slop Field 1."},
	  {ctImageInfoName + "/" + GEImageInfo.SLOP_FLOAT3,
	  "Float Slop Field 1."},
	  {ctImageInfoName + "/" + GEImageInfo.SLOP_FLOAT4,
	  "Float Slop Field 1."},
	  {ctImageInfoName + "/" + GEImageInfo.SLOP_FLOAT5,
	  "Float Slop Field 1."},
	  {ctImageInfoName + "/" + GEImageInfo.SLOP_STR1,
	   "String Slop Field 1."},
	  {ctImageInfoName + "/" + GEImageInfo.SLOP_STR2,
	   "String Slop Field 2."},

	  {ctImageInfoName + "/" + GECTImageInfo.TABLE_START_LOC,
	  "Table Start Location"},
	  {ctImageInfoName + "/" + GECTImageInfo.TABLE_END_LOC,
	  "Table End Location"},
	  {ctImageInfoName + "/" + GECTImageInfo.TABLE_SPEED,
	  "Table Speed (mm/sec)"},
	  {ctImageInfoName + "/" + GECTImageInfo.TABLE_HEIGHT,
	  "Table Height"},
	  {ctImageInfoName + "/" + GECTImageInfo.MID_SCAN_TIME,
	  "Mid Scan Time"},
	  {ctImageInfoName + "/" + GECTImageInfo.MID_SCAN_FLAG,
	  "MidScan flag - does midstime apply for L/S"},
	  {ctImageInfoName + "/" + GECTImageInfo.KVOLT,
	  "generator setting"},
	  {ctImageInfoName + "/" + GECTImageInfo.MAMP,
	  "generator setting"},
	  {ctImageInfoName + "/" + GECTImageInfo.GANTRY_TILT,
	  " Gantry Tilt (degrees)"},
	  {ctImageInfoName + "/" + GECTImageInfo.AZIMUTH,
	  "Degrees of Azimuth"},
	  {ctImageInfoName + "/" + GECTImageInfo.GANTRY_VEL,
	  "Gantry Velocity"},
	  {ctImageInfoName + "/" + GECTImageInfo.GANTRY_FILTER,
	  "Gantry Filter Position"},
	  {ctImageInfoName + "/" + GECTImageInfo.TRIGGER_ON_POS,
	  "Trigger on Position"},
	  {ctImageInfoName + "/" + GECTImageInfo.DEGREE_ROT,
	  "Degrees of rotation"},
	  {ctImageInfoName + "/" + GECTImageInfo.XRAY_ON,
	  "X-Ray On Position"},
	  {ctImageInfoName + "/" + GECTImageInfo.XRAY_OFF,
	  "X-Ray Off Position"},
	  {ctImageInfoName + "/" + GECTImageInfo.NUM_TRIGGERS,
	  "Number of Triggers"},
	  {ctImageInfoName + "/" + GECTImageInfo.INPUT_VIEWS,
	  "Total input views"},
	  {ctImageInfoName + "/" + GECTImageInfo.ANGLE_VIEW1,
	  "Angle of first view"},
	  {ctImageInfoName + "/" + GECTImageInfo.TRIGGER_FREQ,
	  "Trigger frequency"},
	  {ctImageInfoName + "/" + GECTImageInfo.TRIGGER_SRC,
	  "DAS trigger source"},
	  {ctImageInfoName + "/" + GECTImageInfo.FPA_GAIN,
	  "DAS fpa gain"},
	  {ctImageInfoName + "/" + GECTImageInfo.SCAN_TYPE,
	  "Scan Type"},
	  {ctImageInfoName + "/" + GECTImageInfo.OUT_SRC,
	  "DAS output source"},
	  {ctImageInfoName + "/" + GECTImageInfo.AD_INPUT,
	  "DAS ad input"},
	  {ctImageInfoName + "/" + GECTImageInfo.CAL_MODE,
	  "DAS cal mode"},
	  {ctImageInfoName + "/" + GECTImageInfo.CAL_FREQ,
	  "DAS cal frequency"},
	  {ctImageInfoName + "/" + GECTImageInfo.REG_XM,
	  "DAS reg xm"},
	  {ctImageInfoName + "/" + GECTImageInfo.AUTO_ZERO,
	  "DAS auto zero"},
	  {ctImageInfoName + "/" + GECTImageInfo.AXIAL_TYPE,
	  "Axial Type"},
	  {ctImageInfoName + "/" + GECTImageInfo.PHANT_SIZE,
	  "Calibration phantom size"},
	  {ctImageInfoName + "/" + GECTImageInfo.PHANT_TYPE,
	  "Calibration phantom type"},
	  {ctImageInfoName + "/" + GECTImageInfo.FILTER_TYPE,
	  "Calibration filter type"},
	  {ctImageInfoName + "/" + GECTImageInfo.RECON_ALG,
	  "Recon Algorithm"},
	  {ctImageInfoName + "/" + GECTImageInfo.PERIS_FLAG,
	  "Perstaltic flag"},
	  {ctImageInfoName + "/" + GECTImageInfo.ITERBONE_FLAG,
	  "IterBone flag"},
	  {ctImageInfoName + "/" + GECTImageInfo.STAT_FLAG,
	  "Stat Recon flag"},
	  {ctImageInfoName + "/" + GECTImageInfo.COMPUTE_TYPE,
	  "Compute Type"},
	  {ctImageInfoName + "/" + GECTImageInfo.SEG_NUMBER,
	  "Segment Number"},
	  {ctImageInfoName + "/" + GECTImageInfo.SEGS_TOTAL,
	  "Total Number of Segments Requested"},
	  {ctImageInfoName + "/" + GECTImageInfo.ISCAN_DELAY,
	  "Inter scan delay (secs)"},
	  {ctImageInfoName + "/" + GECTImageInfo.SCAN_FIELD,
	  "Scan field of view (mm)"},
	  {ctImageInfoName + "/" + GECTImageInfo.SCAN_NUMBER,
	  "Scan Number"},
	  {ctImageInfoName + "/" + GECTImageInfo.VIEW_START_CHAN,
	  "Starting Channel of View"},
	  {ctImageInfoName + "/" + GECTImageInfo.VIEW_COMP_FACTOR,
	  "View Compression Factor"},
	  {ctImageInfoName + "/" + GECTImageInfo.OUT_VIEWS,
	  "Total Output Views"},
	  {ctImageInfoName + "/" + GECTImageInfo.OVER_RANGES,
	  "Number of Overranges"},
	  {ctImageInfoName + "/" + GECTImageInfo.TOTAL_REF_CHAN,
	  "Total Number of Ref Channels"},
	  {ctImageInfoName + "/" + GECTImageInfo.SCAN_DATA_SIZE,
	  "data size for scan data"},
	  {ctImageInfoName + "/" + GECTImageInfo.REF_CHAN0,
	  "z or q channel"},
	  {ctImageInfoName + "/" + GECTImageInfo.REF_CHAN1,
	  "Reference channel 1"},
	  {ctImageInfoName + "/" + GECTImageInfo.REF_CHAN2,
	  "Reference channel 2"},
	  {ctImageInfoName + "/" + GECTImageInfo.REF_CHAN3,
	  "Reference channel 3"},
	  {ctImageInfoName + "/" + GECTImageInfo.REF_CHAN4,
	  "Reference channel 4"},
	  {ctImageInfoName + "/" + GECTImageInfo.REF_CHAN5,
	  "Reference channel 5"},
	  {ctImageInfoName + "/" + GECTImageInfo.POST_PROC_FLAG,
	  "Recon post processing flag"},
	  {ctImageInfoName + "/" + GECTImageInfo.XM_PATTERN,
	  "DAS xm pattern"},
	  {ctImageInfoName + "/" + GECTImageInfo.ROT_TYPE,
	  "Prescribed rotation type"},
	  {ctImageInfoName + "/" + GECTImageInfo.RAW_DATA_FLAG,
	  "Save Raw Data Flag"},
	  {ctImageInfoName + "/" + GECTImageInfo.CT_SCALE_FACTOR,
	  "IBH Image scale factors"},
	  {ctImageInfoName + "/" + GECTImageInfo.CT_WATER_NUMBER,
	  "CT Water Number"},
	  {ctImageInfoName + "/" + GECTImageInfo.CT_BONE_NUMBER,
	  "CT Bone Number"},
	  {ctImageInfoName + "/" + GECTImageInfo.BBH_COEF1,
	  "BBH coefficient 1"},
	  {ctImageInfoName + "/" + GECTImageInfo.BBH_COEF2,
	  "BBH coefficient 2"},
	  {ctImageInfoName + "/" + GECTImageInfo.BBH_COEF3,
	  "BBH coefficient 3"},
	  {ctImageInfoName + "/" + GECTImageInfo.BBH_NUM_BLEND,
	  "Num of BBH channels to blend"},
	  {ctImageInfoName + "/" + GECTImageInfo.FIRST_CHAN,
	  "Starting channel"},
	  {ctImageInfoName + "/" + GECTImageInfo.NUM_CHAN,
	  "Number of channels (1..512)"},
	  {ctImageInfoName + "/" + GECTImageInfo.CHAN_INCR,
	  "Increment between channels"},
	  {ctImageInfoName + "/" + GECTImageInfo.FIRST_VIEW,
	  "Starting view"},
	  {ctImageInfoName + "/" + GECTImageInfo.NUM_VIEW,
	  "Number of views"},
	  {ctImageInfoName + "/" + GECTImageInfo.VIEW_INCR,
	  "Increment between views"},
	  {ctImageInfoName + "/" + GECTImageInfo.WINDOW_RANGE,
	  "Window Range (0..4095)"},
	  {ctImageInfoName + "/" + GECTImageInfo.SCALE_MIN,
	  "Scaling value of the image data"},
	  {ctImageInfoName + "/" + GECTImageInfo.SCALE_MAX,
	  "Scaling value of the image data"},
	  {ctImageInfoName + "/" + GECTImageInfo.DATA_MODE,
	  "Amount of processing that will be performed"},
	  {ctImageInfoName + "/" + GECTImageInfo.QCAL_FILE,
	  "Source of the qcal vectors"},
	  {ctImageInfoName + "/" + GECTImageInfo.CAL_MOD_FILE,
	  "Source of the cal vectors"},
	  {ctImageInfoName + "/" + GECTImageInfo.WORDS_PER_VIEW,
	  "Number of words per view"},
	  {ctImageInfoName + "/" + GECTImageInfo.RL_RAS,
	  "RAS letter for side of image"},
	  {ctImageInfoName + "/" + GECTImageInfo.AP_RAS,
	  "RAS letter for anterior/posterior"},
	  {ctImageInfoName + "/" + GECTImageInfo.SCOUT_START_RAS,
	  "RAS letter for scout start loc"},
	  {ctImageInfoName + "/" + GECTImageInfo.SCOUT_END_RAS,
	  "RAS letter for scout end loc"},
	  {ctImageInfoName + "/" + GECTImageInfo.SCOUT_ANATOM_REF,
	  "Anatomical reference for scout"},
	  {ctImageInfoName + "/" + GECTImageInfo.PPS_SCALE_WINDOW,
	  "PpScan window range for output Scaling"},
	  {ctImageInfoName + "/" + GECTImageInfo.PPS_QCAL_FLAG,
	  "PpScan Qcal modification flag"},
	  {ctImageInfoName + "/" + GECTImageInfo.PPS_PCAL_FLAG,
	  "PpScan Pcal modification flag"},
	  {ctImageInfoName + "/" + GECTImageInfo.PPS_THETA_FIX,
	  "PpScan Theta Fix (Angle Correction)"},
	  {ctImageInfoName + "/" + GECTImageInfo.PPS_BEAM_FLAG,
	  "PpScan Beam Hardening Flag"},
	  {ctImageInfoName + "/" + GECTImageInfo.SPOT_SIZE,
	  "tube focal spot size"},
	  {ctImageInfoName + "/" + GECTImageInfo.SPOT_POS,
	  "tube focal spot position"},
	  {ctImageInfoName + "/" + GECTImageInfo.RECON_DATA_SET,
	  "Dependent on #views processed"},
	  {ctImageInfoName + "/" + GECTImageInfo.DET_CELL_FIELD,
	  "Field of view in detector cells"},
	  {ctImageInfoName + "/" + GECTImageInfo.SCAN_START_TIME,
	  "Start time(secs) of this scan"},
	  {ctImageInfoName + "/" + GECTImageInfo.GANTRY_DIRECTION,
	  "Gantry Rotation Direction"},
	  {ctImageInfoName + "/" + GECTImageInfo.ROTOR_SPEED,
	  "Tube Rotor Speed"},
	  {ctImageInfoName + "/" + GECTImageInfo.TRIG_MODE,
	  "TGGC Trigger Mode"},
	  {ctImageInfoName + "/" + GECTImageInfo.SI_TILT,
	  "Rx'd gantry tilt - not annotated"},
	  {ctImageInfoName + "/" + GECTImageInfo.R_RECON_CENTER,
	  "R/L coordinate for target recon center"},
	  {ctImageInfoName + "/" + GECTImageInfo.A_RECON_CENTER,
	  "A/P coordinate for target recon center"},
	  {ctImageInfoName + "/" + GECTImageInfo.BACK_PROJ_FLAG,
	  "Value of Back Projection button"},
	  {ctImageInfoName + "/" + GECTImageInfo.FATQ_EST_FLAG,
	  "Set if fatq estimates were used"},
	  {ctImageInfoName + "/" + GECTImageInfo.Z_AVG,
	  "Z chan avg over views"},
	  {ctImageInfoName + "/" + GECTImageInfo.LEFT_REF_AVG,
	  "avg of left ref chans over views"},
	  {ctImageInfoName + "/" + GECTImageInfo.LEFT_REF_MAX,
	  "max left chan value over views"},
	  {ctImageInfoName + "/" + GECTImageInfo.RIGHT_REF_AVG,
	  "avg of right ref chans over views"},
	  {ctImageInfoName + "/" + GECTImageInfo.RIGHT_REF_MAX,
	  "max right chan value over views"},
	  {ctImageInfoName + "/" + GECTImageInfo.BIOPSY_POS,
	  "Biopsy Position"},
	  {ctImageInfoName + "/" + GECTImageInfo.BIOPSY_T_LOC,
	  "Biopsy T Location"},
	  {ctImageInfoName + "/" + GECTImageInfo.BIOPSY_REF_LOC,
	  "Biopsy Ref Location"},
	  {ctImageInfoName + "/" + GECTImageInfo.REF_CHAN,
	  "Reference Channel Used"},
	  {ctImageInfoName + "/" + GECTImageInfo.BP_COEF,
	  "Back Projector Coefficient"},
	  {ctImageInfoName + "/" + GECTImageInfo.PSPEED_CORR,
	  "Primary Speed Correction Used"},
	  {ctImageInfoName + "/" + GECTImageInfo.OVERRANGE_CORR,
	  "Overrange Correction Used"},
	  {ctImageInfoName + "/" + GECTImageInfo.DYN_Z_ALPHA,
	  "Dynamic Z Alpha Value"}
      };	  

      return contents;
    }
}
