/*
  COPYRIGHT NOTICE
  Copyright (c) 2012  Scott C. Neu and Arthur W. Toga

  This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

package edu.ucla.loni.imageio;

import javax.imageio.ImageWriteParam;

/**
 * Image Write Param used to specify LONI-specific image encoding.
 *
 * @version 16 March 2011
 */
public class LoniImageWriteParam extends ImageWriteParam
{
    /** Only write metadata, not image data. */
    private static final int WRITE_ONLY_METADATA = 1;

    /** Only write image data, not metadata. */
    private static final int WRITE_ONLY_IMAGE = 2;

    /** Write both metadata and image data. */
    private static final int WRITE_IMAGE_AND_METADATA = 3;

    /** Write mode. */
    private int _writeMode;

    /** Constructs a LONI Image Write Param. */
    public LoniImageWriteParam()
    {
	_writeMode = WRITE_IMAGE_AND_METADATA;
    }

    /** Sets whether only metadata is written. */
    public void setWriteOnlyMetadata()
    {
	_writeMode = WRITE_ONLY_METADATA;
    }

    /** Sets whether only image data is written. */
    public void setWriteOnlyImage()
    {
	_writeMode = WRITE_ONLY_IMAGE;
    }

    /** Sets whether both metadata and image data are written. */
    public void setWriteImageAndMetadata()
    {
	_writeMode = WRITE_IMAGE_AND_METADATA;
    }

    /**
     * Determines if only metadata is written.
     *
     * @return True if only metadata is written; false otherwise.
     */
    public boolean writeOnlyMetadata()
    {
	return _writeMode == WRITE_ONLY_METADATA;
    }

    /**
     * Determines if only image data is written.
     *
     * @return True if only image data is written; false otherwise.
     */
    public boolean writeOnlyImage()
    {
	return _writeMode == WRITE_ONLY_IMAGE;
    }

    /**
     * Determines if both metadata and image data are written.
     *
     * @return True if both metadata and image data are written; false o/w.
     */
    public boolean writeImageAndMetadata()
    {
	return _writeMode == WRITE_IMAGE_AND_METADATA;
    }
}
