/*
  COPYRIGHT NOTICE
  Copyright (c) 2012  Scott C. Neu and Arthur W. Toga

  This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

package edu.ucla.loni.interfile.plugin;

import edu.ucla.loni.imageio.FileNameAssociator;

/**
 * Interfile Name Associator for generating file name associations between HRRT
 * Interfile files.
 *
 * @version 25 March 2010
 */
public class HrrtInterfileNameAssociator extends InterfileNameAssociator
{
    /** Constructs an HRRT Interfile Name Associator. */
    public HrrtInterfileNameAssociator()
    {
    }

    /**
     * Gets all the allowed file names that can be associated with the specified
     * file name.
     *
     * @param fileName Name of the file to get associated file names for.
     *
     * @return All the allowed file names that can be associated with the
     *         specified file name.  An empty array is returned if there are no
     *         associated file names.
     */
    public String[] getAssociatedFileNames(String fileName)
    {
	// No name 
	if (fileName == null) { return new String[0]; }

	// File is the metadata file
	if ( isMetadataFile(fileName) ) {

	    // Pair FILE.hdr with FILE.i
	    String[] names2 = _getSuffixReplacements(fileName, "hdr", "i");

	    // Pair FILE.hdr with FILE
	    String name = fileName.substring(0, fileName.length()-4);

	    // Combine all the allowed file names
	    String[] names = new String[names2.length+1];
	    System.arraycopy(names2, 0, names, 0, names2.length);
	    names[names2.length] = name;

	    // Return all the allowed file names
	    return names;
	}
	    
	// File is the image pixel file
	else {

	    // Pair FILE.i with FILE.hdr
	    String[] n = new String[0];
	    if ( fileName.toLowerCase().endsWith(".i") ) {
		n = _getSuffixReplacements(fileName, "i", "hdr");
	    }

	    String name1 = fileName + ".hdr";
	    String name2 = fileName + ".HDR";

	    // Combine all the allowed file names
	    String[] names = new String[n.length+2];
	    System.arraycopy(n, 0, names, 0, n.length);
	    names[n.length] = name1;
	    names[n.length+1] = name2;

	    // Return all the allowed file names
	    return names;
 	}
    }
}
