/*
  COPYRIGHT NOTICE
  Copyright (c) 2012  Scott C. Neu and Arthur W. Toga

  This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

package edu.ucla.loni.jdicom.plugin.write;

import edu.ucla.loni.jdicom.DataElement;
import edu.ucla.loni.jdicom.DataSet;
import edu.ucla.loni.jdicom.encoder.DataElementEncoder;
import edu.ucla.loni.jdicom.plugin.OutputStreamAdapter;
import java.io.IOException;
import java.io.OutputStream;
import java.util.Enumeration;
import javax.imageio.stream.ImageOutputStream;

/**
 * DICOM Block for the sequence footer (DICOM tags after 7FE0,0010).
 *
 * @version 15 March 2011
 */
public class SequenceFooter extends DicomBlock
{
    /**
     * Constructs a Sequence Footer.
     *
     * @param outputStream Output stream where the block is written.
     * @param transferSyntax Transfer syntax that determines the encoding.
     * @param dataSet Data Set containing the Data Elements to write.
     *
     * @throws IOException If an error occurs during writing.
     */
    public SequenceFooter(ImageOutputStream outputStream, String transferSyntax,
			  DataSet dataSet)
	throws IOException
    {
	super(outputStream, transferSyntax);

	// Create the encoder
	OutputStream os = new OutputStreamAdapter(outputStream);
	DataElementEncoder encoder = new DataElementEncoder(os, transferSyntax);

	// Write all the Data Elements after the pixel Data Element
	Enumeration enun = dataSet.getDataElements();
	while ( enun.hasMoreElements() ) {
	    DataElement dataElement = (DataElement)enun.nextElement();
	    if ( dataElement.getDataElementTag().compareTo("7FE00010") > 0 ) {
		encoder.writeDataElement(dataElement);
	    }
	}

	// Update the size
	_setSize();
    }
}
