/*
  COPYRIGHT NOTICE
  Copyright (c) 2012  Scott C. Neu and Arthur W. Toga

  This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

package edu.ucla.loni.nrrd;

import java.util.Iterator;
import java.util.LinkedHashSet;

/**
 * NRRD Header Element for a set of Key-Value Pairs.
 *
 * @version 25 October 2010
 */
public class KeyValuePairSet extends NrrdHeaderElement
{
    /** Set of Key-Value Pairs */
    private LinkedHashSet _pairSet;

    /**
     * Constructs a Key-Value Pair Set.
     *
     * @param name Name of the set.
     *
     * @throws IllegalArgumentException If the name is not at least 1 character.
     */
    public KeyValuePairSet(String name)
    {
	super(name);

	// Check the name
	if (name.length() < 1) {
	    throw new IllegalArgumentException("Illegal name");
	}

	_pairSet = new LinkedHashSet();
    }

    /**
     * Gets the name of the Set.
     *
     * @return Name of the Set.
     */
    public String getName()
    {
	return _name;
    }

    /**
     * Maps the key to the value.
     *
     * @param key Key.
     * @param value Value.
     *
     * @throws IllegalArgumentException If the key is not at least 1 character.
     */
    public void setPair(String key, String value)
    {
	// Set a key-value pair
	_pairSet.add( new KeyValuePair(key, value) );
    }

    /**
     * Gets all the Key-Value Pairs.
     *
     * @return All the Key-Value Pairs.
     */
    public KeyValuePair[] getPairs()
    {
	return (KeyValuePair[])_pairSet.toArray(new KeyValuePair[0]);
    }

    /**
     * Determines if this object is equal to the given object.
     *
     * @param obj Object to compare to.
     *
     * @return True if this object is equal to the given object; false o/w.
     */
    public boolean equals(Object obj)
    {
	// Must be a Key-Value Pair Set
	if (obj instanceof KeyValuePairSet) { return super.equals(obj); }
	return false;
    }

    /**
     * Gets a string representation of this Object.
     *
     * @return String representation of this Object.
     */
    public String toString()
    {
	StringBuffer buffer = new StringBuffer("SUBSET " + _name + "\n");

	Iterator iter = _pairSet.iterator();
	while ( iter.hasNext() ) {
	    buffer.append("  " + iter.next() + "\n");
	}

	return buffer.toString();
    }
}
